@@ -8,7 +8,6 @@ from string import capwords
 
 from django.db import models
 from django.db.models.signals import m2m_changed
-from django.dispatch import receiver
 
 from sctel.core.exceptions import IncoerenzaNelleMaschere
 
@@ -18,19 +17,22 @@ MAX_PREFIX_LENGTH = 16
 DEST_TYPES_CHOICES = ((1,'FIX'), (2,'MOB'), (3,'NGN'))
 DEST_TYPES = {'FIX' : 1, 'MOB' : 2, 'NGN': 3}
 
-@receiver(m2m_changed)
-def callback_m2m_changed(sender, **kwargs):
-    if str(sender) == "<class 'alara.prefissi.models.NomeDistretto_prefissi'>":
-        if kwargs['action'] == 'pre_add':
-            # La maschera associata non può contenere prefissi duplicati;
-            #  prefissi già esistenti sotto la stessa maschera vengono rimossi
-            #  dall'attuale nome distretto.
-            maschera = kwargs['instance'].maschera
-            for pk in kwargs['pk_set']:
-                prefisso = Prefisso.objects.get(pk=pk)
-                for nome_distretto in prefisso.nomi_distretto.all():
-                    if nome_distretto.maschera == maschera:
-                        nome_distretto.prefissi.remove(prefisso)
+import django
+if django.VERSION[1] > 2:
+    from django.dispatch import receiver
+    @receiver(m2m_changed)
+    def callback_m2m_changed(sender, **kwargs):
+        if str(sender) == "<class 'sctel.prefissi.models.NomeDistretto_prefissi'>":
+            if kwargs['action'] == 'pre_add':
+                # La maschera associata non può contenere prefissi duplicati;
+                #  prefissi già esistenti sotto la stessa maschera vengono rimossi
+                #  dall'attuale nome distretto.
+                maschera = kwargs['instance'].maschera
+                for pk in kwargs['pk_set']:
+                    prefisso = Prefisso.objects.get(pk=pk)
+                    for nome_distretto in prefisso.nomi_distretto.all():
+                        if nome_distretto.maschera == maschera:
+                            nome_distretto.prefissi.remove(prefisso)
 
 
 class Maschera(models.Model):
@@ -42,6 +44,7 @@ class Maschera(models.Model):
 
     class Meta:
         ordering = ('base', 'nome',)
+        verbose_name_plural = 'Maschere'
 
     def __unicode__(self):
         return self.nome
@@ -72,6 +75,7 @@ class Prefisso(models.Model):
 
     class Meta:
         ordering = ('pre',)
+        verbose_name_plural = 'Prefissi'
 
     def __unicode__(self):
         return self.pre
@@ -106,13 +110,15 @@ class NomeDistretto(models.Model):
     Associazione fra un distretto / carrier e un insieme di prefissi.
     """
     nome = models.CharField(max_length=64)
-    tipo = models.CharField(max_length=3, choices=DEST_TYPES_CHOICES)
-    prefissi = models.ManyToManyField(Prefisso, related_name='nomi_distretto')
+    tipo = models.PositiveIntegerField(choices=DEST_TYPES_CHOICES)
+    prefissi = models.ManyToManyField(Prefisso, blank=True, null=True,
+                                      related_name='nomi_distretto')
     maschera = models.ForeignKey(Maschera)
 
     class Meta:
         ordering = ('maschera', 'nome',)
         unique_together = ('nome', 'maschera',)
+        verbose_name_plural = 'Nomi Distretto'
 
     def __unicode__(self):
         return "%s - %s" % (self.maschera, self.nome)
